#
# spec file for package maven-bundle-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-bundle-plugin
Version:        5.1.9
Release:        4.2
Summary:        Maven Bundle Plugin
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://felix.apache.org
Source0:        https://repo1.maven.org/maven2/org/apache/felix/%{name}/%{version}/%{name}-%{version}-source-release.tar.gz
Patch0:         new-reporting-api.patch
Patch1:         reproducible-from-environment.patch
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(biz.aQute.bnd:biz.aQute.bndlib)
BuildRequires:  mvn(org.apache.felix:felix-parent:pom:)
BuildRequires:  mvn(org.apache.felix:org.apache.felix.bundlerepository)
BuildRequires:  mvn(org.apache.felix:org.apache.felix.utils)
BuildRequires:  mvn(org.apache.maven.doxia:doxia-sink-api) >= 2.0.0
BuildRequires:  mvn(org.apache.maven.doxia:doxia-site-renderer)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-api)
BuildRequires:  mvn(org.apache.maven.shared:maven-dependency-tree)
BuildRequires:  mvn(org.apache.maven:maven-archiver)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-compat)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.codehaus.plexus:plexus-archiver)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.jdom:jdom)
BuildRequires:  mvn(org.osgi:osgi.core)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(org.sonatype.plexus:plexus-build-api)
Provides:       maven-plugin-bundle
Obsoletes:      maven-plugin-bundle
BuildArch:      noarch

%description
Provides a maven plugin that supports creating an OSGi bundle
from the contents of the compilation classpath along with its
resources and dependencies. Plus a zillion other features.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML
Provides:       maven-plugin-bundle-javadoc
Obsoletes:      maven-plugin-bundle-javadoc

%description javadoc
API documentation for %{name}.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1

find -name '*.jar' -delete

%pom_change_dep :org.osgi.core :osgi.core

%pom_remove_plugin :maven-invoker-plugin

%build
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Thu Oct  3 2024 Fridrich Strba <fstrba@suse.com>
- Build against maven-doxia >= 2.0.0
- Modified patch:
  * new-reporting-api.patch
    + adapt to the maven-doxia 2.0.0 APIs
* Mon Sep 23 2024 Fridrich Strba <fstrba@suse.com>
- Use SOURCE_DATE_EPOCH for reproducible builds
- Added patch:
  * reproducible-from-environment.patch
    + SOURCE_DATE_EPOCH environmental variable triggers reproducible
    use of the maven-bundle-plugin if it is not requested already
    using the project.build.outputTimestamp option.
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Sep  2 2023 Fridrich Strba <fstrba@suse.com>
- Rename the package from maven-plugin-bundle to maven-bundle-plugin
  * corresponds to the name of the artifact
- Upgrade to upstream version 5.1.9
  * Bugs
    + FELIX-5794: maven-bundle-plugin fails to parse
    meta-persistence
    + FELIX-6106: Regression after a change in
    maven-bundle-plugin:4.2.0 related to non-existing files
    + FELIX-6187: Avoid overwriting the manifest if it has not
    changed
    + FELIX-6193: Update maven-archiver + plexus-utils
    + FELIX-6203: Make bundleplugin pom.proterties reproducible
    + FELIX-6235: Disallow DTDs when reading OBR repository files
    + FELIX-6269: bundle:manifest generates non-reproducible
    entries in MANIFEST.MF
    + FELIX-6259: java.util.ConcurrentModificationException building
    Apache Commons CSV on Java 15-EA
    + FELIX-6312: Maven Bundle Plugin removes entries from manifest
    since version 5
    + FELIX-6337: Maven Bundle Plugin generates incorrect
    Provide-Capability
    + FELIX-6404: bundle:bundle:5.1.2 add non-reproducible Built-By
    and Build-Jdk to MANIFEST.MF
    + FELIX-6460: {maven-test-sources} not working as expected
    + FELIX-6493: Extend is-up-to-date logic of Manifest goal
    + FELIX-6495: bundle:manifest produces non reproducible
    Bnd-LastModified
    + FELIX-6496: non-reproducible Export-Package and
    Private-Package values
    + FELIX-6526: The "manifest" goal does not work anymore in
    modules which are using aspectj-maven-plugin "compile" goal
    + FELIX-6547: maven-bundle-plugin uses outdated bndlib leading
    to invalid osgi.ee required capability
    + FELIX-6548: NPE in
    org.apache.felix:maven-bundle-plugin:5.1.7:manifest when
    called without clean
  * Improvements
    + Prep for bndlib 4.1.0
    + FELIX-5920: Prepare maven-bundle-plugin for release with
    bndlib 4.0.0
    + FELIX-6073: Upgrade to Maven 3
    + FELIX-6074: Check for stale input and avoid recomputing the
    manifest if no changes
    + FELIX-6075: Upgrade to JDK 8
    + FELIX-6078: Add an option to silently ignore some project
    types instead of displaying a warning
    + FELIX-6081: Upgrade bndlib to 4.2.0 in order to properly
    calculate osgi.ee for embedded dependencies
    + FELIX-6469: automatically add _reproducible instruction if
    Reproducible Builds activated by project.build.outputTimestamp
    property
    + FELIX-6471: make maven-bundle-plugin build reproducible
    + FELIX-6491: Extend List of niceManifest headers
    + FELIX-6494: add version to Created-By Manifest entry
    + FELIX-6550: Improve error messages for MojoExecutionException
  * Wish
    + FELIX-5795: Maven Bundle Plugin Should Upgrade to Use Maven
    Dependency Tree 3.x
- Removed patches:
  * 0001-Port-to-current-maven-dependency-tree.patch
  * 0002-Fix-for-new-maven-archiver.patch
  * 0003-Port-to-plexus-utils-3.0.24.patch
  * 0004-Use-Maven-3-APIs.patch
    + not needed with this version
* Fri Mar 18 2022 Fridrich Strba <fstrba@suse.com>
- Build with the osgi bundle repository by default
* Fri Mar 11 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * new-reporting-api.patch
    + fix building with the new maven-reporting-api
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Sat Apr  6 2019 Jan Engelhardt <jengelh@inai.de>
- Add Group: line for documentation.
* Fri Apr  5 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-plugin-bundle 3.5.1
